==> dde-shell_2.0.3.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>Wifi aan</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>Wifi uit</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock aan</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock uit</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Numeriek toetsenbord aan</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Numeriek toetsenbord uit</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Touchpad aan</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Touchpad uit</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Touchpadschakelaar</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Fn-schakelaar</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Vliegtuigstand aan</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Vliegtuigstand uit</translation>
    </message>
    <message>
        <source>Mute on</source>
        <translation>Dempen aan</translation>
    </message>
    <message>
        <source>Mute off</source>
        <translation>Dempen uit</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Gebalanceerd energieprofiel</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Energiebesparing</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Hoge prestaties</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Vensteranimaties ingeschakeld</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Vensteranimaties uitgeschakeld</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Vensteranimaties kunnen niet worden ingeschakeld</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.15.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>Wifi aan</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>Wifi uit</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock aan</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock uit</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Numeriek toetsenbord aan</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Numeriek toetsenbord uit</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Touchpad aan</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Touchpad uit</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Touchpadschakelaar</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Fn-schakelaar</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Vliegtuigstand aan</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Vliegtuigstand uit</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Gebalanceerd energieprofiel</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Energiebesparing</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Hoge prestaties</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Vensteranimaties ingeschakeld</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Vensteranimaties uitgeschakeld</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Vensteranimaties kunnen niet worden ingeschakeld</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation>Microfoon uit</translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation>Microfoon aan</translation>
    </message>
</context>
</TS>
